---
title: Urubu sites
layout: index
content:
    - urubu-quickstart
    - ref: myhdl_site 
      title: MyHDL
    - ref: dev_myhdl_site
      title: MyHDL development
    - url: http://www.jandecaluwe.com
      title: Jan Decaluwe
    - url: http://music.jandecaluwe.com
      title: Jan Decaluwe / Music
    - url: http://urubu.jandecaluwe.com
      title: This site (Urubu documentation)
---
